import request from '@/utils/request'

// 查询集团新闻列表
export function listWorkJournalism(query) {
  return request({
    url: '/work/workJournalism/list',
    method: 'get',
    params: query
  })
}

// 查询集团新闻统计
export function findWorkJournalismGroupStatus(query) {
  return request({
    url: '/work/workJournalism/findWorkJournalismGroupStatus',
    method: 'get',
    params: query
  })
}

// 查询集团新闻详细
export function getWorkJournalism(id) {
  return request({
    url: '/work/workJournalism/' + id,
    method: 'get'
  })
}

// 新增集团新闻
export function addWorkJournalism(data) {
  return request({
    url: '/work/workJournalism',
    method: 'post',
    data: data
  })
}

// 修改集团新闻
export function updateWorkJournalism(data) {
  return request({
    url: '/work/workJournalism',
    method: 'put',
    data: data
  })
}

// 删除集团新闻
export function delWorkJournalism(id) {
  return request({
    url: '/work/workJournalism/' + id,
    method: 'delete'
  })
}
