<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <el-form-item label="新闻标题" prop="title">
        <el-input
          v-model="queryParams.title"
          placeholder="请输入新闻标题"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="发布时间">
        <el-date-picker
          v-model="daterangeCreateTime"
          style="width: 240px"
          value-format="yyyy-MM-dd"
          type="daterange"
          range-separator="-"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
        ></el-date-picker>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['work:workJournalism:add']"
          >新增</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['work:workJournalism:edit']"
          >修改</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['work:workJournalism:remove']"
          >删除</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['work:workJournalism:export']"
          >导出</el-button
        >
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-tabs type="card" v-model="activeName" @tab-click="handleClick">
      <el-tab-pane :label="tabs.all" name="all"></el-tab-pane>
      <el-tab-pane :label="tabs.yfb" name="yfb"></el-tab-pane>
      <el-tab-pane :label="tabs.dfb" name="dfb"></el-tab-pane>
      <el-table
        v-loading="loading"
        :data="workJournalismList"
        @selection-change="handleSelectionChange" stripe
      >
        <el-table-column type="selection" width="55" align="center" />
        <el-table-column
          label="新闻标题"
          align="center"
          prop="title"
          width="150"
          show-overflow-tooltip
        />
        <el-table-column label="新闻主图" align="center" prop="mainImage" width="200">
          <template slot-scope="scope">
            <el-image
              ref="preview"
              style="width: 200px; height: 100px"
              :src="getImageUrl(scope.row.mainImage)"
              @click="onPreview(scope.row.mainImage)"
            >
            </el-image>
          </template>
        </el-table-column>
        <el-table-column label="简介" align="center" prop="intro" />
        <el-table-column label="新闻状态" align="center" prop="statusFlag">
          <template slot-scope="scope">
            <dict-tag
              :options="dict.type.work_journalism_status"
              :value="scope.row.statusFlag"
            />
          </template>
        </el-table-column>
        <el-table-column label="置顶状态" align="center" prop="topFlag">
          <template slot-scope="scope">
            <dict-tag
              :options="dict.type.work_journalism_top"
              :value="scope.row.topFlag"
            />
          </template>
        </el-table-column>
        <el-table-column
          label="显示排序"
          align="center"
          prop="sortNum"
          v-if="checkPermi(['work:workJournalism:edit'])"
        >
          <template slot-scope="scope">
            <el-input-number
              size="mini"
              v-model="scope.row.sortNum"
              :min="1"
              :max="999"
              @change="setSort(scope.row, $event)"
            ></el-input-number>
          </template>
        </el-table-column>
        <el-table-column label="数据状态" align="center" prop="isDel">
          <template slot-scope="scope">
            <dict-tag :options="dict.type.sys_common_isdel" :value="scope.row.isDel" />
          </template>
        </el-table-column>
        <el-table-column label="发布用户" align="center" prop="createUser" />
        <el-table-column label="发布时间" align="center" prop="updateTime" width="120">
          <template slot-scope="scope">
            <span>{{ parseTime(scope.row.updateTime, "{y}-{m}-{d} {h}:{i}") }}</span>
          </template>
        </el-table-column>
        <el-table-column
          label="操作"
          align="center"
          class-name="small-padding fixed-width"
        >
          <template slot-scope="scope">
            <el-button
              v-if="scope.row.statusFlag == '1' || scope.row.statusFlag == '3'"
              size="mini"
              type="text"
              icon="el-icon-position"
              @click="handleUpdateStatus(scope.row, 2)"
              v-hasPermi="['work:workJournalism:edit']"
              >发布</el-button
            >
            <el-button
              v-if="scope.row.statusFlag == '2'"
              size="mini"
              type="text"
              icon="el-icon-refresh-left"
              @click="handleUpdateStatus(scope.row, 1)"
              v-hasPermi="['work:workJournalism:edit']"
              >撤回</el-button
            >
            <el-button
              v-if="scope.row.topFlag == '0'"
              size="mini"
              type="text"
              icon="el-icon-sort"
              @click="handleUpdateTop(scope.row, 1)"
              v-hasPermi="['work:workJournalism:edit']"
              >置顶</el-button
            >
            <el-button
              v-if="scope.row.topFlag == '1'"
              size="mini"
              type="text"
              icon="el-icon-sort"
              @click="handleUpdateTop(scope.row, 0)"
              v-hasPermi="['work:workJournalism:edit']"
              >取消置顶</el-button
            >
            <el-button
              size="mini"
              type="text"
              icon="el-icon-edit"
              @click="handleUpdate(scope.row)"
              v-hasPermi="['work:workJournalism:edit']"
              >修改</el-button
            >
            <el-button
              size="mini"
              type="text"
              icon="el-icon-delete"
              @click="handleDelete(scope.row)"
              v-hasPermi="['work:workJournalism:remove']"
              >删除</el-button
            >
          </template>
        </el-table-column>
      </el-table>

      <pagination
        v-show="total > 0"
        :total="total"
        :page.sync="queryParams.pageNum"
        :limit.sync="queryParams.pageSize"
        @pagination="getList"
      />
    </el-tabs>
    <!-- 添加或修改集团新闻对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" append-to-body :close-on-click-modal="false" :close-on-press-escape="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="新闻标题" prop="title">
          <el-input v-model="form.title" placeholder="请输入新闻标题" />
        </el-form-item>
        <el-form-item label="新闻主图" prop="mainImage">
          <image-upload v-model="form.mainImage" />
        </el-form-item>
        <el-form-item label="简介" prop="intro">
          <el-input v-model="form.intro" placeholder="请输入简介" />
        </el-form-item>
        <el-form-item label="新闻内容">
          <editor v-model="form.content" :min-height="192" />
        </el-form-item>
        <el-form-item label="相关文件" prop="files">
          <FileUpload @input="fileInput" :limit="9" v-model="files" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
    <el-image-viewer v-if="showViewer" :on-close="closeViewer" :url-list="previewList" />
  </div>
</template>

<script>
import {
  listWorkJournalism,
  getWorkJournalism,
  delWorkJournalism,
  addWorkJournalism,
  updateWorkJournalism,
  findWorkJournalismGroupStatus,
} from "@/api/work/workJournalism";
import ElImageViewer from "element-ui/packages/image/src/image-viewer";
import { checkPermi, checkRole } from "@/utils/permission"; // 权限判断函数

export default {
  name: "WorkJournalism",
  components: {
    ElImageViewer,
  },
  dicts: ["work_journalism_status", "work_journalism_top", "sys_common_isdel"],
  data() {
    return {
      showViewer: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 集团新闻表格数据
      workJournalismList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 备注时间范围
      daterangeCreateTime: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        title: null,
        statusFlag: null,
        topFlag: null,
        sortNum: null,
        isDel: null,
        createTime: null,
        activeName: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        title: [
          { required: true, message: "请输入新闻标题", trigger: "blur" },
          { max: 30, message: "新闻标题最多30个字符", trigger: "blur" },
        ],
        mainImage: [{ required: true, message: "请上传新闻主图", trigger: "blur" }],
        intro: [
          { required: false, message: "请输入新闻简介", trigger: "blur" },
          { max: 200, message: "新闻简介最多200个字符", trigger: "blur" },
        ],
        content: [{ required: true, message: "请输入新闻内容", trigger: "blur" }],
        files: [{ required: false, message: "请上传相关附件", trigger: "blur" }],
      },
      tabs: {
        all: "全部数据（0）",
        yfb: "已发布（0）",
        dfb: "待发布（0）",
      },
      previewList: [],
      files: [],
      activeName: "yfb",
    };
  },
  created() {
    this.queryParams.activeName = this.activeName;
    this.getList();
  },
  methods: {
    checkPermi,
    /** 查询集团新闻列表 */
    getList() {
      this.loading = true;
      this.queryParams.params = {};
      if (null != this.daterangeCreateTime && "" != this.daterangeCreateTime) {
        this.queryParams.params["beginCreateTime"] = this.daterangeCreateTime[0];
        this.queryParams.params["endCreateTime"] = this.daterangeCreateTime[1];
      }
      this.queryCount();
      listWorkJournalism(this.queryParams).then((response) => {
        this.workJournalismList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    queryCount() {
      findWorkJournalismGroupStatus(this.queryParams).then((response) => {
        if (response && response.data) {
          let sum = 0;
          if (response.data.status1) {
            sum += response.data.status1;
          }
          if (response.data.status3) {
            sum += response.data.status3;
          }
          this.tabs.dfb = "待发布（" + sum + "）";
          this.tabs.yfb = "已发布（0）";
          if (response.data.status2) {
            sum += response.data.status2;
            this.tabs.yfb = "已发布（" + response.data.status2 + "）";
          }
          this.tabs.all = "全部数据（" + sum + "）";
        }
      });
    },
    getImageUrl(url) {
      return process.env.VUE_APP_BASE_API + url + ".min.jpg";
    },
    onPreview(url) {
      this.previewList = [];
      this.previewList.push(process.env.VUE_APP_BASE_API + url);
      this.showViewer = true;
    },
    closeViewer() {
      this.showViewer = false;
    },
    // 页签点击
    handleClick() {
      this.queryParams.activeName = this.activeName;
      this.getList();
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        title: null,
        mainImage: null,
        intro: null,
        content: null,
        type: null,
        source: null,
        openUrl: null,
        readNum: null,
        statusFlag: null,
        topFlag: null,
        files: null,
        sortNum: null,
        isDel: null,
        createUser: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.daterangeCreateTime = [];
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加集团新闻";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids;
      getWorkJournalism(id).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改集团新闻";
      });
    },
    //修改新闻状态
    handleUpdateStatus(row, status) {
      const id = row.id || this.ids;
      this.form.id = id;
      this.form.statusFlag = status;
      updateWorkJournalism(this.form).then((response) => {
        this.$modal.msgSuccess("修改成功");
        this.getList();
      });
    },
    //修改新闻状态
    handleUpdateTop(row, top) {
      const id = row.id || this.ids;
      this.form.id = id;
      this.form.topFlag = top;
      updateWorkJournalism(this.form).then((response) => {
        this.$modal.msgSuccess("修改成功");
        this.getList();
      });
    },
    //新闻排序控制
    setProjectSort(row, val) {
      let param = {
        id: row.id,
        sortNum: val,
      };
      updateWorkJournalism(param).then((response) => {
        this.$modal.msgSuccess("修改成功");
        this.getList();
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id) {
            updateWorkJournalism(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            this.form.type = 1;
            this.form.source = 1;
            addWorkJournalism(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm('是否确认删除集团新闻编号为"' + ids + '"的数据项？')
        .then(function () {
          return delWorkJournalism(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    //文件输入
    fileInput(files) {
      let file = "";
      if (files.length > 0) {
        files.forEach((item) => {
          file += "," + item.url;
        });
        this.form.files = file.substring(1);
      }
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download(
        "work/workJournalism/export",
        {
          ...this.queryParams,
        },
        `workJournalism_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
